#ifndef Application_h
#define Application_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "Counter.h"
#include "File.h"
#include "FileList.h"
#include "IconEngine.h"

#include <memory>

class MainWindow;

//* application controler
class Application: public BaseApplication, public Counter
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    Application( CommandLineArguments );

    //* application manager
    virtual bool initApplicationManager( void );

    //* create all widgets
    bool realizeWidget( void );

    //* file list
    FileList& recentFiles( void ) const
    { return *recentFiles_; }

    //* retrieves top layout
    MainWindow & mainWindow( void ) const
    { return *mainWindow_; }

    //*@name application information
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const;

    //* command line help
    void usage( void ) const;

    //* application name
    virtual QString applicationName( void ) const
    { return "Textool"; }

    //* application icon
    virtual QIcon applicationIcon( void ) const
    { return IconEngine::get( ":/textool.png" ); }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    //@}


    public Q_SLOTS:

    //* add recent file
    void addRecentFile( File );

    protected Q_SLOTS:

    //* configuration
    void _configuration( void );

    //* process request from application manager
    virtual bool _processCommand( Server::ServerCommand );

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration( void );

    private:

    //* recent files list
    std::unique_ptr<FileList> recentFiles_;

    //* top widget
    MainWindow *mainWindow_ = nullptr;

};

#endif
