#ifndef DefaultOptions_h
#define DefaultOptions_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LatexCommand.h"
#include "File.h"
#include "XmlOptions.h"
#include "TexFile.h"
#include "Util.h"

//_____________________________________________________
//* default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().set<int>( "DB_SIZE", 10 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 350 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 600 );

    XmlOptions::get().set<bool>( "SAVE_BACKUP", false );
    XmlOptions::get().set<bool>( "AUTO_BIBTEX", true );

    // tooltips in recent files list
    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", true );

    // auto cleaning
    for( const auto& extension:TexFile::cleanExtensions() )
    {
        const QString optionName = "AUTO_CLEAN_"+extension;
        XmlOptions::get().set<bool>( optionName, true );
    }

    unsigned int actionState =
        (1<<LatexCommand::Latex)|
        (1<<LatexCommand::DviPS)|
        (1<<LatexCommand::Check)|
        (1<<LatexCommand::Clean);
    XmlOptions::get().set<int>( "ACTIONS", actionState );

    // resource file
    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".textoolrc").addPath( Util::home() ), Option::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File("textoolrc").addPath( Util::config() ), Option::None ) );

    XmlOptions::get().setAutoDefault( false );

};

#endif
