/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FigureModel.h"

#include "MimeTypeIconProvider.h"

#include <QUrl>


//______________________________________________________________________
FigureModel::FigureModel( QObject* parent ):
  FileRecordModel( parent ),
  mimeTypeIconProvider_( new MimeTypeIconProvider( this ) )
{}

//______________________________________________________________________
File FigureModel::filename( const QModelIndex& index ) const
{

    static QString extensions[] = { "pdf", "eps", "png", "jpg", "gif", QString() };

    if( !index.isValid() ) return File();

    const FileRecord record( get(index) );
    File file( record.file() );
    if( file.exists() ) return file;
    else {

        for( int i=0; !extensions[i].isNull(); ++i )
        {
            File local( QString( "%1.%2" ).arg( file.truncatedName() ).arg( extensions[i] ) );
            if( local.exists() ) return local;
        }

        return file;
    }

}

//______________________________________________________________________
File::List FigureModel::filenames( const QModelIndexList& indexes ) const
{
    File::List files;
    for( const auto& index:indexes )
    { files.append( filename( index ) ); }

    return files;
}

//__________________________________________________________________
QVariant FigureModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    if( role == Qt::DecorationRole && index.column() == Filename )
    {

        return mimeTypeIconProvider_->icon( filename( index ).extension() );

    } else return FileRecordModel::data( index, role );

}

//______________________________________________________________________
QMimeData* FigureModel::mimeData(const QModelIndexList &indexes) const
{

    // get selected filenames
    File::List files( filenames( indexes ) );

    QOrderedSet<QString> filenames;
    for( const auto& file:files )
    { if( !file.isEmpty() ) filenames.insert( file ); }

    if( filenames.empty() ) return nullptr;
    else {

        QMimeData* mimeData = new QMimeData();

        // fill text data
        {
            QString fullText;
            QTextStream buffer( &fullText );
            for( const auto& filename:filenames )
            { buffer << QString( "file://%1" ).arg(filename) << endl; }
            mimeData->setText( fullText );
        }

        // fill url list
        {
            QList<QUrl> urlList;
            for( const auto& filename:filenames )
            { urlList.append( QUrl( QString( "file://%1" ).arg(filename) ) ); }
            mimeData->setUrls( urlList );
        }

        return mimeData;

    }

}
