#ifndef HelpText_h
#define HelpText_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

static const QString helpText[] =
{
    //_________________________________________________________
    QObject::tr( "Introduction" ),
    QObject::tr( "<h2>Introduction</h2>"
    "<p>TexTool is a Qt based user interface to LaTeX software and related. It integrates all steps needed to process a tex source file and create a postscript or PDF (portable document format) document out of it. in a single panel. It also handles the different file extensions in a user transparent way. Finally it offers some utilities for undefined references/citations checking as well as file editing. Printing of the generated postscript or PDF files is not supported by the application, since it is already provided by most postscript and PDF viewer.</p>"
    "<p> It must be stressed that since TexTool is only an interface, none of the applications which are needed to go from the tex to the postscript file are provided by the application. They must be installed independently an TexTool must be configured accordingly. See the <i>required software</i> section for details." ),

    //_________________________________________________________
    QObject::tr( "Requirements" ),
    QObject::tr( "<h2>Requirements</h2>"
    "<p>Several software are required to convert a LaTeX source file to a postscript/pdf file. None of these is provided by TexTool. These software are:<ul><li><i>latex</i>, which converts the original .tex file into a .dvi file;<li><i>dvips</i> or any other working dvi to postscript converter;<li><i>pstopdf</i> or any other working postscript to pdf converter;<li><i>xdvi</i> or any other working dvi file viewer;<li><i>a postscript viewer</i> to display postscript files on screen;<li><i>a pdf viewer</i> to display the pdf files on screen;<li><i>a text editor</i> to edit the latex source files.</ul>A default value for all these applications is provided in the TexTool configuration dialog opened via <i>Settings::Configuration</i>. </p>"
    "<p>None of these applications is mandatory for TexTool to run. If an application is not found, the corresponding functionality is disabled and the user gets warned when trying to access it.</p>"
    "<p>Related: Preference Menu/Button Frame" ),

    //_________________________________________________________
    QObject::tr( "File Menu" ),
    QObject::tr( "<h2>File Menu</h2>"
    "<p>The File Menu is located in the application menu bar. It displays the following buttons: "
    "<ul>"
    "<li><i>Open</i>: select a <i>project</i> file. By project we call either a tex, dvi postscript, pdf, (...) file, from a latex project. The extension of the file is of no importance since it will get overwritten automatically depending on the action which is performed. More precisely,</li>"
    "<ul>"
    "<li>latex runs on a <i>.tex</i> file and produces a <i>.dvi</i> file;</li>"
    "<li>dvips runs on a <i>.dvi</i> file and produces a <i>.ps</i> file;</li>"
    "<li>pstopdf runs on a <i>.ps</i> file and produces a <i>.pdf</i> file;</li>"
    "<li>etc.</li>"
    "</ul>"
    "once selected the file appears in the file selection frame.</li>"
    "<li><i>Open previous</i>: display a menu of all recently opened projects from which the use can select one.<li><i>Exit</i>: exits the application.</li>"
    "</ul>"
    "<p>Related: File Selection Frame." ),

    //_________________________________________________________
    QObject::tr( "Edit Menu" ),
    QObject::tr( "<h2>Edit Menu</h2>"
    "The Edit Menu is located in the application menu bar. It allows the user to edit all latex related files based on it's extension. A button is displayed for each possible possible extension for latex related file. When selected, the corresponding extension is appended to the file found in the File Selection Frame and the result gets edited. </p>"
    "<p>The last button (<i>Raw</i>) is used to edit the file found in the file selection frame <i>as is</i> (i.e. without modifying its extension).</p>"
    "<p>Note: A text editor must be provided to the application for this functionality to be available.</p>"
    "<p>related: File Selection Frame/Preference menu.</p>" ),

    //_________________________________________________________
    QObject::tr( "Settings Menu" ),
    QObject::tr( "<h2>Settings Menu</h2>"
    "<p>The Settings menu is located in the menu bar and allows to open the application <i>Configuration</i> dialog.</p>" ),

    //_________________________________________________________
    QObject::tr( "File Selection" ),
    QObject::tr( "<h2>File Selection</h2>"
    "<p>The file selection displays the file on which the latex commands are applied. It's extension is changed automatically depending of the command. It can be modified directly, via a file selection dialog opened using the <i>[...]</i> button locating next to the line editor; using <i>File::Open</i> or using <i>File::Open Previous</i>. </p>"
    "<p>Related: File Menu</p>" ),

    //_________________________________________________________
    QObject::tr( "Actions" ),
    QObject::tr( "<h2>Actions</h2>"
    "<p>The actions frame contains a list of check-boxes to control which applications are used to process the latex document.</p>"
    "<p>The list of available actions is:</p>"
    "<ul>"
    "<li><i>Latex</i>: to run latex on the .tex file</li>"
    "<li><i>Bibtex</i>: to create the file bibliography from included .bib files</li>"
    "<li><i>Dvi to PS</i>: to convert the .dvi file into a .ps postscript file </li>"
    "<li><i>Dvi to PS</i>: to convert the .dvi file into a .pdf file </li>"
    "<li><i>PS to PDF</i>: converts the .ps postscript into a .pdf file </li>"
    "<li><i>Check</i>: to check for undefined references, duplicate labels and undefined citations. It also displays the order in which citations are used and should appear in the bibliography.</li>"
    "<li><i>Clean</i>: to remove all temporary files</li>"
    "</ul>"
    "<p>A <i>Run</i> button located at the bottom of the frame runs all selected actions sequentially. Once pressed, it is changed into <i>Abort</i> to stop the processing at any time, notably when one of the selected actions failed and the .tex file needs modification. The output of the actions is reported in the log frame (see corresponding section in this help). </p>"
    "<p>Related: Log Frame</p>" ),

    //_________________________________________________________
    QObject::tr( "Utilities" ),
    QObject::tr( "<h2>Utilities</h2>"
    "<p>The utilities frame contains a list of visualization tools and other utilities for the tex document. They are: </p>"
    "<ul>"
    "<li><i>Edit Tex</i> to edit current .tex file;</li>"
    "<li><i>View DVI</i> to display the .dvi file;</li>"
    "<li><i>View PS</i> to display the postscript file;</li>"
    "<li><i>View PDF</i>: to display the .pdf file;</li>"
    "<li><i>Clean</i>: to remove all temporary files</li>"
    "</ul>"
    "<p>The various applications associated to the buttons above can be set/changed in the Preference Menu.</p>"
    "<p>Related: Include Frame/Preference Menu</p>" ),

    //_________________________________________________________
    QObject::tr( "Log" ),
    QObject::tr( "<h2>Log</h2>"
    "<p>The log frame is located in the main window. It can be displayed using the tabs, or detached in a separate window. It collects all the output of the latex document processing and report on failure. It is cleared every time the Run button in the action frame is pressed.</p>"
    "<p>Related: Action Frame</p>" ),

    //_________________________________________________________
    QObject::tr( "Includes" ),
    QObject::tr( "<h2>Includes</h2>"
    "<p>The include frame displays the list of .tex files that are included in the main file. Right clicking in the list opens a menu that allows to edit or run the spell checker on the selected files. Each item in the list has a check-box. When the later is unchecked, the corresponding file is unchecked from the main file, so that it is not processed when running latex.</p>"
    "<p>Related: File Selection Frame</p>" ),

    //_________________________________________________________
    QObject::tr( "Figures" ),
    QObject::tr( "<h2>Figures</h2>"
    "<p>The figure frame displays the list of postscript figures that are included in the main file that appears in the File Selection Frame. Right clicking in the list allows to display the figure using the Postscript viewer specified in the options.</p>" ),

    //_________________________________________________________
    QObject::tr( "State Frame" ),
    QObject::tr( "<h2>State Frame</h2>"
    "<p>The state frame is located at the bottom of the main window and displays various information on the file selection, the application that has been run, and the TexTool status.</p>" ),
    0
};

#endif
