/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "IncludeFileModel.h"

//! column titles
const QString IncludeFileModel::columnTitles_[ IncludeFileModel::nColumns ] =
{
    tr( "File" ),
    tr( "Included" ),
    QString()
};

//_______________________________________________________________
IncludeFileModel::IncludeFileModel( QObject* parent ):
    TreeModel<IncludeFile>( parent ),
    Counter( "IncludeFileModel" )
{ Debug::Throw( "IncludeFileModel::IncludeFileModel.\n" ); }


//__________________________________________________________________
QVariant IncludeFileModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "IncludeFileModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();
    if( role == Qt::DisplayRole && index.column() == Filename ) return _find( index.internalId() ).get().file().localName();
    else if( role == Qt::CheckStateRole && index.column() == Selection )
    {
        if( !parent( index ).isValid() ) return QVariant();
        else return _find( index.internalId() ).get().isSelected() ? Qt::Checked : Qt::Unchecked;
    }

    return QVariant();

}

//__________________________________________________________________
QVariant IncludeFileModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}
