#ifndef IncludeFileModel_h
#define IncludeFileModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "IncludeFile.h"
#include "TreeModel.h"

//* FileRecord model. Store File records in hierarchy list.
class IncludeFileModel : public TreeModel<IncludeFile>, public Counter
{

    Q_OBJECT

    public:

    //* column type enumeration
    enum ColumnType
    {
        Filename,
        Selection,
        Empty,
        nColumns
    };

    //* constructor
    IncludeFileModel(QObject* = nullptr);

    //*@name methods reimplemented from base class
    //@{

    // return File for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //* header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //* number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    protected:

    //* sorting
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private:

    //* column titles
    static const QString columnTitles_[ nColumns ];

};

#endif
