/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TexString.h"
#include "File.h"

//________________________________________________________
const QString& TexString::header( void )
{
    static const QString header_(
        "\\NeedsTeXFormat{LaTeX2e}\n"
        "\\documentclass[10pt,a4paper]{article}\n"
        "\\usepackage[utf8]{inputenc}\n"
        "\\usepackage[T1]{fontenc}\n"
        "\n"
        "\\hoffset 0.cm\n"
        "\\voffset 1.cm\n"
        "\\oddsidemargin 0.cm\n"
        "\\evensidemargin 0.cm\n"
        "\\topmargin 0.cm\n"
        "\\headheight 0.mm\n"
        "\\headsep 0.mm\n"
        "\\textheight 23.cm\n"
        "\\textwidth 16.2cm\n"\
        "\\marginparsep 0.cm\n"
        "\\marginparwidth 0.cm\n"
        "\\footskip 1.cm\n"
        "\\parskip 3mm\n"
        "\\parindent 0mm\n"
        "\n"
        "\\begin{document}\n");
    return header_;
}

//________________________________________________________
const QString& TexString::trailer( void )
{
    static const QString trailer_( "\n\\end{document}\n" );
    return trailer_;
}

//________________________________________________________
QString TexString::toLatexAccents( void ) const
{
    QString out( *this );
    for( const auto& conversion:_conversions() )
    { if( !conversion.first.isEmpty() ) out = out.replace( conversion.first, conversion.second ); }
    return out;
}

//________________________________________________________
QString TexString::toTextAccents( void ) const
{
    QString out( *this );
    for( const auto& conversion:_conversions() )
    { if( !conversion.second.isEmpty() ) out = out.replace( conversion.second, conversion.first ); }
    return out;
}

//________________________________________________________
const TexString::ConversionList& TexString::_conversions( void )
{
    static ConversionList conversions_;

    if( conversions_.empty() )
    {
        conversions_ << Conversion( QString::fromUtf8( "à" ), "\\`a" );
        conversions_ << Conversion( QString::fromUtf8( "â" ), "\\^a" );
        conversions_ << Conversion( QString::fromUtf8( "ä" ), "\\\"a" );
        conversions_ << Conversion( QString::fromUtf8( "é" ), "\\'e" );
        conversions_ << Conversion( QString::fromUtf8( "è" ), "\\`e" );
        conversions_ << Conversion( QString::fromUtf8( "ê" ), "\\^e" );
        conversions_ << Conversion( QString::fromUtf8( "ë" ), "\\\"e" );
        conversions_ << Conversion( QString::fromUtf8( "î" ), "\\^\\i " );
        conversions_ << Conversion( QString::fromUtf8( "ï" ), "\\\"\\i " );
        conversions_ << Conversion( QString::fromUtf8( "ô" ), "\\^o" );
        conversions_ << Conversion( QString::fromUtf8( "ö" ), "\\\"o" );
        conversions_ << Conversion( QString::fromUtf8( "ù" ), "\\`u" );
        conversions_ << Conversion( QString::fromUtf8( "û" ), "\\^u" );
        conversions_ << Conversion( QString::fromUtf8( "ç" ), "\\c c" );
    }

    return conversions_;

}
